<?php

namespace Drupal\recommend_nodes\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Session\AccountProxyInterface;


/**
 * Class RecommendForm.
 */
class RecommendForm extends FormBase {

  /**
   * Drupal\Core\Session\AccountProxyInterface definition.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Drupal\Core\Database\Connection definition.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
  
  
  /**
   * {@inheritdoc}
   */
  public function __construct(AccountProxyInterface $currentUserManager, Connection $dbconnection) {
   $this->currentUser = $currentUserManager;
   $this->connection = $dbconnection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
		$container->get('current_user'),
		$container->get('database')
    );
  }
  
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'recommend_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $id = NULL) {
    $form['user_name'] = [
      '#type' => 'entity_autocomplete',
	  '#target_type' => 'user',
	  '#tags' => TRUE,
      '#title' => $this->t('User name'),
      '#description' => $this->t('Select a user to whom you want to recommend'),
      '#weight' => '0',
    ];
	$form['recommend_text'] = [
      '#type' => 'textarea',
	  '#maxlength' => 128,
      '#title' => $this->t('Recommend note'),
    ];
	$form['id'] = [
      '#type' => 'hidden',
      '#value' => $id,
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    foreach ($form_state->getValues() as $key => $value) {
      // @TODO: Validate fields.
    }
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    foreach ($form_state->getValue('user_name') as $key => $value) {
		$result = $this->connection->insert('recommend_nodes')
			->fields([
			'recommend_to' => $value['target_id'],
			'recommend_by' => $this->currentUser->id(),
			'recommend_text' => $form_state->getValue('recommend_text'),
			'nid' => $form_state->getValue('id'),
			'recommend_date' => REQUEST_TIME,
			'accept_deny' => 0,
		])
		->execute();
    }
	\Drupal::messenger()->addMessage("You successfully add the record");
  }
}
